summaryrefslogtreecommitdiff
path: root/sc/source/ui/view/output2.cxx
diff options
context:
space:
mode:
authorEike Rathke <erack@redhat.com>2011-11-28 02:49:11 +0100
committerEike Rathke <erack@redhat.com>2011-11-28 15:25:32 +0100
commit16252e44a3a1bf2414ea64455e6bf016ec5b7d04 (patch)
tree3c015bf291b98fcb5483894ce03520b136bcd8dd /sc/source/ui/view/output2.cxx
parent0c428b052fa0599637497f289e57858fcca4c4e2 (diff)
dr78: #i116691# don't reduce decimals if formula is shown
# HG changeset patch # User Niklas Nebel <nn@openoffice.org> # Date 1297087576 -3600 # Node ID 37cf78c63d8ec7609c254e58316902d5bdb48618 # Parent 4e7aa2262f3ae26e6082f475ef06bbabf39b3e93
Diffstat (limited to 'sc/source/ui/view/output2.cxx')
-rw-r--r--sc/source/ui/view/output2.cxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/sc/source/ui/view/output2.cxx b/sc/source/ui/view/output2.cxx
index 5f1e109bf516..de1506a6089f 100644
--- a/sc/source/ui/view/output2.cxx
+++ b/sc/source/ui/view/output2.cxx
@@ -551,9 +551,9 @@ void ScDrawStringsVars::SetTextToWidthOrHash( ScBaseCell* pCell, long nWidth )
if (eType == CELLTYPE_FORMULA)
{
ScFormulaCell* pFCell = static_cast<ScFormulaCell*>(pCell);
- if (pFCell->GetErrCode() != 0)
+ if (pFCell->GetErrCode() != 0 || pOutput->bShowFormulas)
{
- SetHashText(); // If the error string doesn't fit, always use "###"
+ SetHashText(); // If the error string doesn't fit, always use "###". Also for "display formulas" (#i116691#)
return;
}
// If it's formula, the result must be a value.